//*****************************************************************************
//*****************************************************************************
//  FILENAME:   sensor.h
//  Version: 1.0, 2007/03/08 
//  Generated by Andy Kiser
//
//  DESCRIPTION:  Sensor specific functions and declarations
//
//-----------------------------------------------------------------------------
// Originally authored by Toradex AG. This work is now available under the terms and conditions
// of the Creative Commons License 'Attribution CC BY', details of which can be found here:
// http://creativecommons.org/licenses/by/3.0/
//*****************************************************************************
//*****************************************************************************
#include <m8c.h>
#include "parameters.h"

//-----------------------------------------------------------------------------
// Sensor parameters
// the first parameters (lowest indices) are identical for each sensor
// additional parameters may be defined here 
//-----------------------------------------------------------------------------
// actual used number of parameters
// --> see also #define MAX_PARAM_8 ... in parameters.h
#define NUM_PARAM_8		2	
#define NUM_PARAM_16	3	
#define NUM_PARAM_32	1
#define NUM_PARAM_168	6

// Assignment of Parameters
#define PAR8_REPORTMODE	0
#define PAR8_LEDMODE 1

#define PAR16_REPORTRATE_MS	0
#define PAR16_SAMPLERATE_MS	1
#define PAR16_SAMPLERATE_US	2

#define PAR32_DUMMY			0

#define PAR168_USRDEVNAME	0
#define PAR168_USRCHNAME_0	1
#define PAR168_USRCHNAME_1	2
#define PAR168_USRCHNAME_2	3


// factory defaults are defined in the source file of the sensor
extern	const BYTE			FactoryDefault_Param_8   [NUM_PARAM_8];
extern	const WORD			FactoryDefault_Param_16  [NUM_PARAM_16];
extern	const DWORD			FactoryDefault_Param_32  [NUM_PARAM_32];
extern	const tParam_168	FactoryDefault_Param_168 [NUM_PARAM_168];

//-----------------------------------------------------------------------------
// Type Definitions
//-----------------------------------------------------------------------------
typedef struct
{
	BYTE Relay[4];
} tOutReport;

typedef struct
{
	BYTE FrameNr_LSB;
	BYTE FrameNr_MSB;
	BYTE Relay[4];
} tInReport;


//-----------------------------------------------------------------------------
// Global Variables
//-----------------------------------------------------------------------------
extern tInReport	InReport;
extern tOutReport	OutReport;
extern tInReport	InReport;
#define EP_IN  2
#define EP_OUT 4

#define IN_REPORT_SIZE (sizeof(tInReport))
#define OUT_REPORT_SIZE (sizeof(tOutReport))

extern BOOL	NewSample;
extern BYTE NofOutBytes; // number of bytes that were read in the last OUT report
//-----------------------------------------------------------------------------
// Initializes the MS5534 
//-----------------------------------------------------------------------------
extern void Sensor_Start (void);

//-----------------------------------------------------------------------------
// Prepare Measurement for Suspend
//-----------------------------------------------------------------------------
extern void Sensor_Suspend(void);

//-----------------------------------------------------------------------------
// Send Sequence to Start Temperature Measurement
//-----------------------------------------------------------------------------
extern void Sensor_Resume(void);

//-----------------------------------------------------------------------------
// void Sensor_FSM_Measure(void)
//
//	finite state machine to control the measurement process for 
//  the SCA100T sensor
//
//  IMPORTANT: 	call this routine once every millisecond. Otherwise the timing
//				parameters cannot be met.
//-----------------------------------------------------------------------------
extern void Sensor_FSM_Measure(void);

//-----------------------------------------------------------------------------
// void Sensor_FSM_Uart(void)
//
//	finite state machine to control the serial communication to the Magellan
//  motor controller
//
//  Requires the following GLOBAL variables to be set up properly
//   UartTxReport	Data to Transmit
//	 UartTxSize		Number of Bytes to Transmit
//	 UartRxSize		Expected number of response bytes
//  Affects the following GLOBAL variables
//   FSM_Uart   	Sure, this is the idea behind a state machine
//   UartError  	Kind of error. Valid if [FSM_Uart==eUartError]
//   Uart_ms 		only used in this function, and related initialization function
//	 UartRxReport	Contains the received UART data
//   
//
//  IMPORTANT: 	call this routine once every millisecond. Otherwise the timing
//				parameters cannot be met.
//-----------------------------------------------------------------------------
extern void Sensor_FSM_Uart (void);

//-----------------------------------------------------------------------------
// Function that will be called when a FEATURE REPORT is received that 
// cannot be handled with the standard functionality in feature.c
// The feature report data is available in the "FEATURE_RPT" variable
//
// --> see feature.c for an example how to parse FEATURE_RPT
//
//	return Value: number of Parameter bytes (1-31) that are 
//				  returned in the IN report
//-----------------------------------------------------------------------------
extern BYTE Sensor_Specific_Feature(void);

//-----------------------------------------------------------------------------
// Function that will be called when a FEATURE REPORT is received that 
// sets / gets a 8/16/32/168bit parameter in feature.c
// The feature report data is available in the "FEATURE_RPT" variable
//
// --> see feature.c for an example how to parse FEATURE_RPT
//-----------------------------------------------------------------------------
extern void Sensor_Specific_Parameter(BYTE *NumberOfReturnedBytes);

//-----------------------------------------------------------------------------
// debug function
//-----------------------------------------------------------------------------
extern void Sensor_Debug(void);

// end of file sensor.h
